@@ -12,14 +12,16 @@ context("Schmidt (MinFunc) Armijo Line Search")
 mfls <- function(fg, x, pv, alpha, c1, LS_interp = 2, LS_multi = 0, debug = FALSE) {
   step0 <- make_step0(fg, x, pv)
 
-  res <- ArmijoBacktrack(alpha, f = step0$f, g = step0$df,
-                         gtd = step0$d,
-                         c1 = c1,
-                         LS_interp = LS_interp, LS_multi = LS_multi,
-                         funObj = make_phi_alpha(x, fg, pv, calc_gradient_default = TRUE),
-                         varargin = NULL,
-                         pnorm_inf = max(abs(pv)),
-                         progTol = 1e-9, debug = debug)
+  res <- ArmijoBacktrack(alpha,
+    f = step0$f, g = step0$df,
+    gtd = step0$d,
+    c1 = c1,
+    LS_interp = LS_interp, LS_multi = LS_multi,
+    funObj = make_phi_alpha(x, fg, pv, calc_gradient_default = TRUE),
+    varargin = NULL,
+    pnorm_inf = max(abs(pv)),
+    progTol = 1e-9, debug = debug
+  )
 
   res$step$par <- x + res$step$alpha * pv
   res
@@ -27,20 +29,20 @@ mfls <- function(fg, x, pv, alpha, c1, LS_interp = 2, LS_multi = 0, debug = FALS
 
 # Table 1
 test_that("Table 1 Grad/Cubic Interpolation", {
-  pv1 <- -f1$gr(0)/abs(f1$gr(0))
+  pv1 <- -f1$gr(0) / abs(f1$gr(0))
   res11 <- mfls(fg = f1, x = 0, pv = pv1, alpha = 1e-3, c1 = 0.001, LS_interp = 2, LS_multi = 0)
   expect_step(res11, x = 1e-3, f = -5e-4, df = -0.5, nfev = 1)
   res12 <- mfls(fg = f1, x = 0, pv = pv1, alpha = 1e-1, c1 = 0.001, LS_interp = 2, LS_multi = 0)
   expect_step(res12, x = 1e-1, f = -0.049751, df = -0.49256, nfev = 1)
   res13 <- mfls(fg = f1, x = 0, pv = pv1, alpha = 1e1, c1 = 0.001, LS_interp = 2, LS_multi = 0)
-  expect_step(res13, x = 1e1, f = -0.098039, df =  0.0094195, nfev = 1)
+  expect_step(res13, x = 1e1, f = -0.098039, df = 0.0094195, nfev = 1)
   res14 <- mfls(fg = f1, x = 0, pv = pv1, alpha = 1e3, c1 = 0.001, LS_interp = 2, LS_multi = 0)
   expect_step(res14, x = 37.054, f = -0.026948, df = 7.2516e-004, nfev = 4)
 })
 
 # Table 2
 test_that("Table 2 Grad/Cubic Interpolation", {
-  pv2 <- -f2$gr(0)/abs(f2$gr(0))
+  pv2 <- -f2$gr(0) / abs(f2$gr(0))
   res21 <- mfls(fg = f2, x = 0, pv = pv2, alpha = 1e-3, c1 = 0.1, LS_interp = 2, LS_multi = 0)
   expect_step(res21, x = 0.001, f = -1.2469e-9, df = -9.9688e-007, nfev = 1)
   res22 <- mfls(fg = f2, x = 0, pv = pv2, alpha = 1e-1, c1 = 0.1, LS_interp = 2, LS_multi = 0)
@@ -53,11 +55,11 @@ test_that("Table 2 Grad/Cubic Interpolation", {
 
 # Table 3
 test_that("Table 3 Grad/Cubic Interpolation", {
-  pv3 <- -f3$gr(0)/abs(f3$gr(0))
+  pv3 <- -f3$gr(0) / abs(f3$gr(0))
   res31 <- mfls(fg = f3, x = 0, pv = pv3, alpha = 1e-3, c1 = 0.1, LS_interp = 2, LS_multi = 0)
-  expect_step(res31, x = 1e-3, f = 0.99999, df =  -0.011857, nfev = 1)
+  expect_step(res31, x = 1e-3, f = 0.99999, df = -0.011857, nfev = 1)
   res32 <- mfls(fg = f3, x = 0, pv = pv3, alpha = 1e-1, c1 = 0.1, LS_interp = 2, LS_multi = 0)
-  expect_step(res32, x = 1e-1, f =  0.89747, df = -0.022189, nfev = 1)
+  expect_step(res32, x = 1e-1, f = 0.89747, df = -0.022189, nfev = 1)
   res33 <- mfls(fg = f3, x = 0, pv = pv3, alpha = 1e1, c1 = 0.1, LS_interp = 2, LS_multi = 0)
   expect_step(res33, x = 0.020790, f = 0.99466, df = -0.71010, nfev = 2)
   res34 <- mfls(fg = f3, x = 0, pv = pv3, alpha = 1e3, c1 = 0.1, LS_interp = 2, LS_multi = 0)
@@ -66,7 +68,7 @@ test_that("Table 3 Grad/Cubic Interpolation", {
 
 # Table 4
 test_that("Table 4 Grad/Cubic Interpolation", {
-  pv4 <- -f4$gr(0)/abs(f4$gr(0))
+  pv4 <- -f4$gr(0) / abs(f4$gr(0))
   res41 <- mfls(fg = f4, x = 0, pv = pv4, alpha = 1e-3, c1 = 0.001, LS_interp = 2, LS_multi = 0)
   expect_step(res41, x = 1e-3, f = 0.99941, df = -0.29260, nfev = 1)
   res42 <- mfls(fg = f4, x = 0, pv = pv4, alpha = 1e-1, c1 = 0.001, LS_interp = 2, LS_multi = 0)
@@ -79,7 +81,7 @@ test_that("Table 4 Grad/Cubic Interpolation", {
 
 # Table 5
 test_that("Table 5 Grad/Cubic Interpolation", {
-  pv5 <- -f5$gr(0)/abs(f5$gr(0))
+  pv5 <- -f5$gr(0) / abs(f5$gr(0))
   res51 <- mfls(fg = f5, x = 0, pv = pv5, alpha = 1e-3, c1 = 0.001, LS_interp = 2, LS_multi = 0)
   expect_step(res51, x = 1e-3, f = 0.99910, df = -0.89065, nfev = 1)
   res52 <- mfls(fg = f5, x = 0, pv = pv5, alpha = 1e-1, c1 = 0.001, LS_interp = 2, LS_multi = 0)
@@ -92,7 +94,7 @@ test_that("Table 5 Grad/Cubic Interpolation", {
 
 # Table 6
 test_that("Table 6 Grad/Cubic Interpolation", {
-  pv6 <- -f6$gr(0)/abs(f6$gr(0))
+  pv6 <- -f6$gr(0) / abs(f6$gr(0))
   res61 <- mfls(fg = f6, x = 0, pv = pv6, alpha = 1e-3, c1 = 0.001, LS_interp = 2, LS_multi = 0)
   expect_step(res61, x = 1e-3, f = 0.99945, df = -0.29888, nfev = 1)
   res62 <- mfls(fg = f6, x = 0, pv = pv6, alpha = 1e-1, c1 = 0.001, LS_interp = 2, LS_multi = 0)
@@ -107,20 +109,20 @@ test_that("Table 6 Grad/Cubic Interpolation", {
 
 # Table 1
 test_that("Table 1 Grad/Quartic/Quintic Interpolation", {
-  pv1 <- -f1$gr(0)/abs(f1$gr(0))
+  pv1 <- -f1$gr(0) / abs(f1$gr(0))
   res11 <- mfls(fg = f1, x = 0, pv = pv1, alpha = 1e-3, c1 = 0.001, LS_interp = 2, LS_multi = 1)
   expect_step(res11, x = 1e-3, f = -5e-4, df = -0.5, nfev = 1)
   res12 <- mfls(fg = f1, x = 0, pv = pv1, alpha = 1e-1, c1 = 0.001, LS_interp = 2, LS_multi = 1)
   expect_step(res12, x = 1e-1, f = -0.049751, df = -0.49256, nfev = 1)
   res13 <- mfls(fg = f1, x = 0, pv = pv1, alpha = 1e1, c1 = 0.001, LS_interp = 2, LS_multi = 1)
-  expect_step(res13, x = 1e1, f = -0.098039, df =  0.0094195, nfev = 1)
+  expect_step(res13, x = 1e1, f = -0.098039, df = 0.0094195, nfev = 1)
   res14 <- mfls(fg = f1, x = 0, pv = pv1, alpha = 1e3, c1 = 0.001, LS_interp = 2, LS_multi = 1)
   expect_step(res14, x = 27.506, f = -0.036260, df = 0.0013113, nfev = 4)
 })
 
 # Table 2
 test_that("Table 2 Grad/Quartic/Quintic Interpolation", {
-  pv2 <- -f2$gr(0)/abs(f2$gr(0))
+  pv2 <- -f2$gr(0) / abs(f2$gr(0))
   res21 <- mfls(fg = f2, x = 0, pv = pv2, alpha = 1e-3, c1 = 0.1, LS_interp = 2, LS_multi = 1)
   expect_step(res21, x = 0.001, f = -1.2469e-9, df = -9.9688e-007, nfev = 1)
   res22 <- mfls(fg = f2, x = 0, pv = pv2, alpha = 1e-1, c1 = 0.1, LS_interp = 2, LS_multi = 1)
@@ -133,11 +135,11 @@ test_that("Table 2 Grad/Quartic/Quintic Interpolation", {
 
 # Table 3
 test_that("Table 3 Grad/Quartic/Quintic Interpolation", {
-  pv3 <- -f3$gr(0)/abs(f3$gr(0))
+  pv3 <- -f3$gr(0) / abs(f3$gr(0))
   res31 <- mfls(fg = f3, x = 0, pv = pv3, alpha = 1e-3, c1 = 0.1, LS_interp = 2, LS_multi = 1)
-  expect_step(res31, x = 1e-3, f = 0.99999, df =  -0.011857, nfev = 1)
+  expect_step(res31, x = 1e-3, f = 0.99999, df = -0.011857, nfev = 1)
   res32 <- mfls(fg = f3, x = 0, pv = pv3, alpha = 1e-1, c1 = 0.1, LS_interp = 2, LS_multi = 1)
-  expect_step(res32, x = 1e-1, f =  0.89747, df = -0.022189, nfev = 1)
+  expect_step(res32, x = 1e-1, f = 0.89747, df = -0.022189, nfev = 1)
   res33 <- mfls(fg = f3, x = 0, pv = pv3, alpha = 1e1, c1 = 0.1, LS_interp = 2, LS_multi = 1)
   expect_step(res33, x = 0.020790, f = 0.99466, df = -0.71010, nfev = 2)
   res34 <- mfls(fg = f3, x = 0, pv = pv3, alpha = 1e3, c1 = 0.1, LS_interp = 2, LS_multi = 1)
@@ -146,7 +148,7 @@ test_that("Table 3 Grad/Quartic/Quintic Interpolation", {
 
 # Table 4
 test_that("Table 4 Grad/Quartic/Quintic Interpolation", {
-  pv4 <- -f4$gr(0)/abs(f4$gr(0))
+  pv4 <- -f4$gr(0) / abs(f4$gr(0))
   res41 <- mfls(fg = f4, x = 0, pv = pv4, alpha = 1e-3, c1 = 0.001, LS_interp = 2, LS_multi = 1)
   expect_step(res41, x = 1e-3, f = 0.99941, df = -0.29260, nfev = 1)
   res42 <- mfls(fg = f4, x = 0, pv = pv4, alpha = 1e-1, c1 = 0.001, LS_interp = 2, LS_multi = 1)
@@ -159,7 +161,7 @@ test_that("Table 4 Grad/Quartic/Quintic Interpolation", {
 
 # Table 5
 test_that("Table 5 Grad/Quartic/Quintic Interpolation", {
-  pv5 <- -f5$gr(0)/abs(f5$gr(0))
+  pv5 <- -f5$gr(0) / abs(f5$gr(0))
   res51 <- mfls(fg = f5, x = 0, pv = pv5, alpha = 1e-3, c1 = 0.001, LS_interp = 2, LS_multi = 1)
   expect_step(res51, x = 1e-3, f = 0.99910, df = -0.89065, nfev = 1)
   res52 <- mfls(fg = f5, x = 0, pv = pv5, alpha = 1e-1, c1 = 0.001, LS_interp = 2, LS_multi = 1)
@@ -172,7 +174,7 @@ test_that("Table 5 Grad/Quartic/Quintic Interpolation", {
 
 # Table 6
 test_that("Table 6 Grad/Quartic/Quintic Interpolation", {
-  pv6 <- -f6$gr(0)/abs(f6$gr(0))
+  pv6 <- -f6$gr(0) / abs(f6$gr(0))
   res61 <- mfls(fg = f6, x = 0, pv = pv6, alpha = 1e-3, c1 = 0.001, LS_interp = 2, LS_multi = 1)
   expect_step(res61, x = 1e-3, f = 0.99945, df = -0.29888, nfev = 1)
   res62 <- mfls(fg = f6, x = 0, pv = pv6, alpha = 1e-1, c1 = 0.001, LS_interp = 2, LS_multi = 1)
@@ -187,20 +189,20 @@ test_that("Table 6 Grad/Quartic/Quintic Interpolation", {
 
 # Table 1
 test_that("Table 1 BT/Quad Interpolation", {
-  pv1 <- -f1$gr(0)/abs(f1$gr(0))
+  pv1 <- -f1$gr(0) / abs(f1$gr(0))
   res11 <- mfls(fg = f1, x = 0, pv = pv1, alpha = 1e-3, c1 = 0.001, LS_interp = 1, LS_multi = 0)
   expect_step(res11, x = 1e-3, f = -5e-4, df = -0.5, nfev = 1)
   res12 <- mfls(fg = f1, x = 0, pv = pv1, alpha = 1e-1, c1 = 0.001, LS_interp = 1, LS_multi = 0)
   expect_step(res12, x = 1e-1, f = -0.049751, df = -0.49256, nfev = 1)
   res13 <- mfls(fg = f1, x = 0, pv = pv1, alpha = 1e1, c1 = 0.001, LS_interp = 1, LS_multi = 0)
-  expect_step(res13, x = 1e1, f = -0.098039, df =  0.0094195, nfev = 1)
+  expect_step(res13, x = 1e1, f = -0.098039, df = 0.0094195, nfev = 1)
   res14 <- mfls(fg = f1, x = 0, pv = pv1, alpha = 1e3, c1 = 0.001, LS_interp = 1, LS_multi = 0)
   expect_step(res14, x = 31.271, f = -0.031913, df = 0.0010164, nfev = 6)
 })
 
 # Table 2
 test_that("Table 2 BT/Quad Interpolation", {
-  pv2 <- -f2$gr(0)/abs(f2$gr(0))
+  pv2 <- -f2$gr(0) / abs(f2$gr(0))
   res21 <- mfls(fg = f2, x = 0, pv = pv2, alpha = 1e-3, c1 = 0.1, LS_interp = 1, LS_multi = 0)
   expect_step(res21, x = 0.001, f = -1.2469e-9, df = -9.9688e-007, nfev = 1)
   res22 <- mfls(fg = f2, x = 0, pv = pv2, alpha = 1e-1, c1 = 0.1, LS_interp = 1, LS_multi = 0)
@@ -208,16 +210,16 @@ test_that("Table 2 BT/Quad Interpolation", {
   res23 <- mfls(fg = f2, x = 0, pv = pv2, alpha = 1e1, c1 = 0.1, LS_interp = 1, LS_multi = 0)
   expect_step(res23, x = 0.01, f = -7.6294e-008, df = -2.1760e-005, nfev = 2)
   res24 <- mfls(fg = f2, x = 0, pv = pv2, alpha = 1e3, c1 = 0.1, LS_interp = 1, LS_multi = 0)
-  expect_step(res24, x = 1, f =  -1.0120, df = -3.0159, nfev = 2)
+  expect_step(res24, x = 1, f = -1.0120, df = -3.0159, nfev = 2)
 })
 
 # Table 3
 test_that("Table 3 BT/Quad Interpolation", {
-  pv3 <- -f3$gr(0)/abs(f3$gr(0))
+  pv3 <- -f3$gr(0) / abs(f3$gr(0))
   res31 <- mfls(fg = f3, x = 0, pv = pv3, alpha = 1e-3, c1 = 0.1, LS_interp = 1, LS_multi = 0)
-  expect_step(res31, x = 1e-3, f = 0.99999, df =  -0.011857, nfev = 1)
+  expect_step(res31, x = 1e-3, f = 0.99999, df = -0.011857, nfev = 1)
   res32 <- mfls(fg = f3, x = 0, pv = pv3, alpha = 1e-1, c1 = 0.1, LS_interp = 1, LS_multi = 0)
-  expect_step(res32, x = 1e-1, f =  0.89747, df = -0.022189, nfev = 1)
+  expect_step(res32, x = 1e-1, f = 0.89747, df = -0.022189, nfev = 1)
   res33 <- mfls(fg = f3, x = 0, pv = pv3, alpha = 1e1, c1 = 0.1, LS_interp = 1, LS_multi = 0)
   expect_step(res33, x = 0.061728, f = 0.92862, df = -1.7941, nfev = 2)
   res34 <- mfls(fg = f3, x = 0, pv = pv3, alpha = 1e3, c1 = 0.1, LS_interp = 1, LS_multi = 0)
@@ -226,7 +228,7 @@ test_that("Table 3 BT/Quad Interpolation", {
 
 # Table 4
 test_that("Table 4 BT/Quad Interpolation", {
-  pv4 <- -f4$gr(0)/abs(f4$gr(0))
+  pv4 <- -f4$gr(0) / abs(f4$gr(0))
   res41 <- mfls(fg = f4, x = 0, pv = pv4, alpha = 1e-3, c1 = 0.001, LS_interp = 1, LS_multi = 0)
   expect_step(res41, x = 1e-3, f = 0.99941, df = -0.29260, nfev = 1)
   res42 <- mfls(fg = f4, x = 0, pv = pv4, alpha = 1e-1, c1 = 0.001, LS_interp = 1, LS_multi = 0)
@@ -239,7 +241,7 @@ test_that("Table 4 BT/Quad Interpolation", {
 
 # Table 5
 test_that("Table 5 BT/Quad Interpolation", {
-  pv5 <- -f5$gr(0)/abs(f5$gr(0))
+  pv5 <- -f5$gr(0) / abs(f5$gr(0))
   res51 <- mfls(fg = f5, x = 0, pv = pv5, alpha = 1e-3, c1 = 0.001, LS_interp = 1, LS_multi = 0)
   expect_step(res51, x = 1e-3, f = 0.99910, df = -0.89065, nfev = 1)
   res52 <- mfls(fg = f5, x = 0, pv = pv5, alpha = 1e-1, c1 = 0.001, LS_interp = 1, LS_multi = 0)
@@ -252,7 +254,7 @@ test_that("Table 5 BT/Quad Interpolation", {
 
 # Table 6
 test_that("Table 6 BT/Quad Interpolation", {
-  pv6 <- -f6$gr(0)/abs(f6$gr(0))
+  pv6 <- -f6$gr(0) / abs(f6$gr(0))
   res61 <- mfls(fg = f6, x = 0, pv = pv6, alpha = 1e-3, c1 = 0.001, LS_interp = 1, LS_multi = 0)
   expect_step(res61, x = 1e-3, f = 0.99945, df = -0.29888, nfev = 1)
   res62 <- mfls(fg = f6, x = 0, pv = pv6, alpha = 1e-1, c1 = 0.001, LS_interp = 1, LS_multi = 0)
@@ -267,20 +269,20 @@ test_that("Table 6 BT/Quad Interpolation", {
 
 # Table 1
 test_that("Table 1 BT/Cubic Interpolation", {
-  pv1 <- -f1$gr(0)/abs(f1$gr(0))
+  pv1 <- -f1$gr(0) / abs(f1$gr(0))
   res11 <- mfls(fg = f1, x = 0, pv = pv1, alpha = 1e-3, c1 = 0.001, LS_interp = 1, LS_multi = 1)
   expect_step(res11, x = 1e-3, f = -5e-4, df = -0.5, nfev = 1)
   res12 <- mfls(fg = f1, x = 0, pv = pv1, alpha = 1e-1, c1 = 0.001, LS_interp = 1, LS_multi = 1)
   expect_step(res12, x = 1e-1, f = -0.049751, df = -0.49256, nfev = 1)
   res13 <- mfls(fg = f1, x = 0, pv = pv1, alpha = 1e1, c1 = 0.001, LS_interp = 1, LS_multi = 1)
-  expect_step(res13, x = 1e1, f = -0.098039, df =  0.0094195, nfev = 1)
+  expect_step(res13, x = 1e1, f = -0.098039, df = 0.0094195, nfev = 1)
   res14 <- mfls(fg = f1, x = 0, pv = pv1, alpha = 1e3, c1 = 0.001, LS_interp = 1, LS_multi = 1)
   expect_step(res14, x = 40.021, f = -0.024956, df = 6.2202e-004, nfev = 5)
 })
 
 # Table 2
 test_that("Table 2 BT/Cubic Interpolation", {
-  pv2 <- -f2$gr(0)/abs(f2$gr(0))
+  pv2 <- -f2$gr(0) / abs(f2$gr(0))
   res21 <- mfls(fg = f2, x = 0, pv = pv2, alpha = 1e-3, c1 = 0.1, LS_interp = 1, LS_multi = 1)
   expect_step(res21, x = 0.001, f = -1.2469e-9, df = -9.9688e-007, nfev = 1)
   res22 <- mfls(fg = f2, x = 0, pv = pv2, alpha = 1e-1, c1 = 0.1, LS_interp = 1, LS_multi = 1)
@@ -290,16 +292,16 @@ test_that("Table 2 BT/Cubic Interpolation", {
   res23 <- mfls(fg = f2, x = 0, pv = pv2, alpha = 1e1, c1 = 0.1, LS_interp = 1, LS_multi = 1)
   expect_step(res23, x = 0.01, f = -7.6294e-008, df = -2.1760e-005, nfev = 2)
   res24 <- mfls(fg = f2, x = 0, pv = pv2, alpha = 1e3, c1 = 0.1, LS_interp = 1, LS_multi = 1)
-  expect_step(res24, x = 1, f =  -1.0120, df = -3.0159, nfev = 2)
+  expect_step(res24, x = 1, f = -1.0120, df = -3.0159, nfev = 2)
 })
 
 # Table 3
 test_that("Table 3 BT/Cubic Interpolation", {
-  pv3 <- -f3$gr(0)/abs(f3$gr(0))
+  pv3 <- -f3$gr(0) / abs(f3$gr(0))
   res31 <- mfls(fg = f3, x = 0, pv = pv3, alpha = 1e-3, c1 = 0.1, LS_interp = 1, LS_multi = 1)
-  expect_step(res31, x = 1e-3, f = 0.99999, df =  -0.011857, nfev = 1)
+  expect_step(res31, x = 1e-3, f = 0.99999, df = -0.011857, nfev = 1)
   res32 <- mfls(fg = f3, x = 0, pv = pv3, alpha = 1e-1, c1 = 0.1, LS_interp = 1, LS_multi = 1)
-  expect_step(res32, x = 1e-1, f =  0.89747, df = -0.022189, nfev = 1)
+  expect_step(res32, x = 1e-1, f = 0.89747, df = -0.022189, nfev = 1)
   res33 <- mfls(fg = f3, x = 0, pv = pv3, alpha = 1e1, c1 = 0.1, LS_interp = 1, LS_multi = 1)
   expect_step(res33, x = 0.061728, f = 0.92862, df = -1.7941, nfev = 2)
   res34 <- mfls(fg = f3, x = 0, pv = pv3, alpha = 1e3, c1 = 0.1, LS_interp = 1, LS_multi = 1)
@@ -308,7 +310,7 @@ test_that("Table 3 BT/Cubic Interpolation", {
 
 # Table 4
 test_that("Table 4 BT/Cubic Interpolation", {
-  pv4 <- -f4$gr(0)/abs(f4$gr(0))
+  pv4 <- -f4$gr(0) / abs(f4$gr(0))
   res41 <- mfls(fg = f4, x = 0, pv = pv4, alpha = 1e-3, c1 = 0.001, LS_interp = 1, LS_multi = 1)
   expect_step(res41, x = 1e-3, f = 0.99941, df = -0.29260, nfev = 1)
   res42 <- mfls(fg = f4, x = 0, pv = pv4, alpha = 1e-1, c1 = 0.001, LS_interp = 1, LS_multi = 1)
@@ -321,7 +323,7 @@ test_that("Table 4 BT/Cubic Interpolation", {
 
 # Table 5
 test_that("Table 5 BT/Cubic Interpolation", {
-  pv5 <- -f5$gr(0)/abs(f5$gr(0))
+  pv5 <- -f5$gr(0) / abs(f5$gr(0))
   res51 <- mfls(fg = f5, x = 0, pv = pv5, alpha = 1e-3, c1 = 0.001, LS_interp = 1, LS_multi = 1)
   expect_step(res51, x = 1e-3, f = 0.99910, df = -0.89065, nfev = 1)
   res52 <- mfls(fg = f5, x = 0, pv = pv5, alpha = 1e-1, c1 = 0.001, LS_interp = 1, LS_multi = 1)
@@ -334,7 +336,7 @@ test_that("Table 5 BT/Cubic Interpolation", {
 
 # Table 6
 test_that("Table 6 BT/Cubic Interpolation", {
-  pv6 <- -f6$gr(0)/abs(f6$gr(0))
+  pv6 <- -f6$gr(0) / abs(f6$gr(0))
   res61 <- mfls(fg = f6, x = 0, pv = pv6, alpha = 1e-3, c1 = 0.001, LS_interp = 1, LS_multi = 1)
   expect_step(res61, x = 1e-3, f = 0.99945, df = -0.29888, nfev = 1)
   res62 <- mfls(fg = f6, x = 0, pv = pv6, alpha = 1e-1, c1 = 0.001, LS_interp = 1, LS_multi = 1)
@@ -350,20 +352,20 @@ test_that("Table 6 BT/Cubic Interpolation", {
 
 # Table 1
 test_that("Table 1 BT/Fixed", {
-  pv1 <- -f1$gr(0)/abs(f1$gr(0))
+  pv1 <- -f1$gr(0) / abs(f1$gr(0))
   res11 <- mfls(fg = f1, x = 0, pv = pv1, alpha = 1e-3, c1 = 0.001, LS_interp = 0)
   expect_step(res11, x = 1e-3, f = -5e-4, df = -0.5, nfev = 1)
   res12 <- mfls(fg = f1, x = 0, pv = pv1, alpha = 1e-1, c1 = 0.001, LS_interp = 0)
   expect_step(res12, x = 1e-1, f = -0.049751, df = -0.49256, nfev = 1)
   res13 <- mfls(fg = f1, x = 0, pv = pv1, alpha = 1e1, c1 = 0.001, LS_interp = 0)
-  expect_step(res13, x = 1e1, f = -0.098039, df =  0.0094195, nfev = 1)
+  expect_step(res13, x = 1e1, f = -0.098039, df = 0.0094195, nfev = 1)
   res14 <- mfls(fg = f1, x = 0, pv = pv1, alpha = 1e3, c1 = 0.001, LS_interp = 0)
   expect_step(res14, x = 31.250, f = -0.031935, df = 0.0010177, nfev = 6)
 })
 
 # Table 2
 test_that("Table 2 BT/Fixed", {
-  pv2 <- -f2$gr(0)/abs(f2$gr(0))
+  pv2 <- -f2$gr(0) / abs(f2$gr(0))
   res21 <- mfls(fg = f2, x = 0, pv = pv2, alpha = 1e-3, c1 = 0.1, LS_interp = 0)
   expect_step(res21, x = 0.001, f = -1.2469e-9, df = -9.9688e-007, nfev = 1)
   res22 <- mfls(fg = f2, x = 0, pv = pv2, alpha = 1e-1, c1 = 0.1, LS_interp = 0)
@@ -376,11 +378,11 @@ test_that("Table 2 BT/Fixed", {
 
 # Table 3
 test_that("Table 3 BT/Fixed", {
-  pv3 <- -f3$gr(0)/abs(f3$gr(0))
+  pv3 <- -f3$gr(0) / abs(f3$gr(0))
   res31 <- mfls(fg = f3, x = 0, pv = pv3, alpha = 1e-3, c1 = 0.1, LS_interp = 0)
-  expect_step(res31, x = 1e-3, f = 0.99999, df =  -0.011857, nfev = 1)
+  expect_step(res31, x = 1e-3, f = 0.99999, df = -0.011857, nfev = 1)
   res32 <- mfls(fg = f3, x = 0, pv = pv3, alpha = 1e-1, c1 = 0.1, LS_interp = 0)
-  expect_step(res32, x = 1e-1, f =  0.89747, df = -0.022189, nfev = 1)
+  expect_step(res32, x = 1e-1, f = 0.89747, df = -0.022189, nfev = 1)
   res33 <- mfls(fg = f3, x = 0, pv = pv3, alpha = 1e1, c1 = 0.1, LS_interp = 0)
   expect_step(res33, x = 1.25, f = 0.26493, df = 1.3789, nfev = 4)
   res34 <- mfls(fg = f3, x = 0, pv = pv3, alpha = 1e3, c1 = 0.1, LS_interp = 0)
@@ -389,7 +391,7 @@ test_that("Table 3 BT/Fixed", {
 
 # Table 4
 test_that("Table 4 BT/Fixed", {
-  pv4 <- -f4$gr(0)/abs(f4$gr(0))
+  pv4 <- -f4$gr(0) / abs(f4$gr(0))
   res41 <- mfls(fg = f4, x = 0, pv = pv4, alpha = 1e-3, c1 = 0.001, LS_interp = 0)
   expect_step(res41, x = 1e-3, f = 0.99941, df = -0.29260, nfev = 1)
   res42 <- mfls(fg = f4, x = 0, pv = pv4, alpha = 1e-1, c1 = 0.001, LS_interp = 0)
@@ -402,7 +404,7 @@ test_that("Table 4 BT/Fixed", {
 
 # Table 5
 test_that("Table 5 BT/Fixed", {
-  pv5 <- -f5$gr(0)/abs(f5$gr(0))
+  pv5 <- -f5$gr(0) / abs(f5$gr(0))
   res51 <- mfls(fg = f5, x = 0, pv = pv5, alpha = 1e-3, c1 = 0.001, LS_interp = 0)
   expect_step(res51, x = 1e-3, f = 0.99910, df = -0.89065, nfev = 1)
   res52 <- mfls(fg = f5, x = 0, pv = pv5, alpha = 1e-1, c1 = 0.001, LS_interp = 0)
@@ -415,7 +417,7 @@ test_that("Table 5 BT/Fixed", {
 
 # Table 6
 test_that("Table 6 BT/Fixed", {
-  pv6 <- -f6$gr(0)/abs(f6$gr(0))
+  pv6 <- -f6$gr(0) / abs(f6$gr(0))
   res61 <- mfls(fg = f6, x = 0, pv = pv6, alpha = 1e-3, c1 = 0.001, LS_interp = 0)
   expect_step(res61, x = 1e-3, f = 0.99945, df = -0.29888, nfev = 1)
   res62 <- mfls(fg = f6, x = 0, pv = pv6, alpha = 1e-1, c1 = 0.001, LS_interp = 0)
